@@ -68,7 +68,6 @@ GtkWidget *totem_pp_create (void);
 #endif
 
 typedef enum {
-	TOTEM_PLUGIN_TYPE_BASIC,
 	TOTEM_PLUGIN_TYPE_GMP,
 	TOTEM_PLUGIN_TYPE_COMPLEX,
 	TOTEM_PLUGIN_TYPE_NARROWSPACE,
@@ -304,9 +303,9 @@ totem_embedded_set_error (TotemEmbedded *emb,
 			  int code,
 			  char *secondary)
 {
-	emb->error = g_error_new (TOTEM_EMBEDDED_ERROR_QUARK,
-				  code,
-				  secondary);
+	emb->error = g_error_new_literal (TOTEM_EMBEDDED_ERROR_QUARK,
+	                                  code,
+	                                  secondary);
 	g_message ("totem_embedded_set_error: '%s'", secondary);
 }
 
@@ -460,10 +459,10 @@ totem_embedded_open_internal (TotemEmbedded *emb,
 		uri = emb->current_uri;
 
 	if (!uri) {
-		g_set_error (error,
-			     TOTEM_EMBEDDED_ERROR_QUARK,
-			     TOTEM_EMBEDDED_NO_URI,
-			     _("No URI to play"));
+		g_set_error_literal (error,
+                                     TOTEM_EMBEDDED_ERROR_QUARK,
+                                     TOTEM_EMBEDDED_NO_URI,
+                                     _("No URI to play"));
 		//FIXME totem_embedded_set_error (emb, error); |error| may be null?
 
 		return FALSE;
@@ -583,9 +582,9 @@ totem_embedded_do_command (TotemEmbedded *embedded,
 	}
 		
 	g_set_error (error,
-		     TOTEM_EMBEDDED_ERROR_QUARK,
-		     TOTEM_EMBEDDED_UNKNOWN_COMMAND,
-		     "Unknown command '%s'", command);
+                     TOTEM_EMBEDDED_ERROR_QUARK,
+                     TOTEM_EMBEDDED_UNKNOWN_COMMAND,
+                     "Unknown command '%s'", command);
 	return FALSE;
 }
 
@@ -663,45 +662,85 @@ totem_embedded_launch_player (TotemEmbedded *embedded,
 }
 
 static char *
-resolve_uri (const char *base_uri,
-             const char *relative_uri)
+relative_uri_remove_query (const char *uri, char **query)
 {
-  char *uri, *scheme;
-  GFile *base_gfile, *base_parent_gfile, *resolved_gfile;
+	char *qmark;
 
-  if (!relative_uri)
-    return g_strdup (base_uri);
+	/* Look for '?' */
+	qmark = strrchr (uri, '?');
+	if (qmark == NULL)
+		return NULL;
 
-  if (!base_uri)
-    return g_strdup (relative_uri);
+	*query = g_strdup (qmark);
+	return g_strndup (uri, qmark - uri);
+}
 
-  /* If |relative_uri| has a scheme, it's a full URI, just return it */
-  scheme = g_uri_parse_scheme (relative_uri);
-  if (scheme) {
-    g_free (scheme);
-    return g_strdup (relative_uri);
-  }
+static char *
+resolve_uri (const char *base_uri,
+	     const char *relative_uri)
+{
+	char *uri, *scheme, *query, *new_relative_uri;
+	GFile *base_gfile, *base_parent_gfile, *resolved_gfile;
 
-  base_gfile = g_file_new_for_uri (base_uri);
-  base_parent_gfile = g_file_get_parent (base_gfile);
-  if (!base_parent_gfile) {
-    g_print ("Base URI %s has no parent!\n", base_uri);
-    g_object_unref (base_gfile);
-    return NULL;
-  }
-  g_object_unref (base_gfile);
+	if (!relative_uri)
+		return g_strdup (base_uri);
 
-  resolved_gfile = g_file_resolve_relative_path (base_parent_gfile, relative_uri);
-  g_object_unref (base_parent_gfile);
-  if (!resolved_gfile) {
-    g_warning ("Failed to resolve relative URI '%s' against base '%s'\n", relative_uri, base_uri);
-    return NULL;
-  }
+	if (!base_uri)
+		return g_strdup (relative_uri);
 
-  uri = g_file_get_uri (resolved_gfile);
-  g_object_unref (resolved_gfile);
+	/* If |relative_uri| has a scheme, it's a full URI, just return it */
+	scheme = g_uri_parse_scheme (relative_uri);
+	if (scheme) {
+		g_free (scheme);
+		return g_strdup (relative_uri);
+	}
 
-  return uri;
+	base_gfile = g_file_new_for_uri (base_uri);
+	base_parent_gfile = g_file_get_parent (base_gfile);
+	if (!base_parent_gfile) {
+		g_print ("Base URI %s has no parent!\n", base_uri);
+		g_object_unref (base_gfile);
+		return NULL;
+	}
+	g_object_unref (base_gfile);
+
+	query = NULL;
+	new_relative_uri = relative_uri_remove_query (relative_uri, &query);
+
+	if (new_relative_uri) {
+		char *tmpuri;
+
+		resolved_gfile = g_file_resolve_relative_path (base_parent_gfile, new_relative_uri);
+		g_object_unref (base_parent_gfile);
+		if (!resolved_gfile) {
+			g_warning ("Failed to resolve relative URI '%s' against base '%s'\n", relative_uri, base_uri);
+			g_free (new_relative_uri);
+			g_free (query);
+			return NULL;
+		}
+
+		tmpuri = g_file_get_uri (resolved_gfile);
+		g_object_unref (resolved_gfile);
+		uri = g_strdup_printf ("%s%s", tmpuri, query);
+
+		g_free (tmpuri);
+		g_free (new_relative_uri);
+		g_free (query);
+
+		return uri;
+	} else {
+		resolved_gfile = g_file_resolve_relative_path (base_parent_gfile, relative_uri);
+		g_object_unref (base_parent_gfile);
+		if (!resolved_gfile) {
+			g_warning ("Failed to resolve relative URI '%s' against base '%s'\n", relative_uri, base_uri);
+			return NULL;
+		}
+
+		uri = g_file_get_uri (resolved_gfile);
+		g_object_unref (resolved_gfile);
+
+		return uri;
+	}
 }
 
 static void
@@ -721,7 +760,10 @@ totem_embedded_set_uri (TotemEmbedded *emb,
 	emb->is_browser_stream = (is_browser_stream != FALSE);
 	emb->href_uri = NULL;
 
-        g_print ("totem_embedded_set_uri uri %s base %s => resolved %s\n", uri, base_uri, emb->current_uri);
+	if (uri != NULL)
+		g_print ("totem_embedded_set_uri uri %s base %s => resolved %s\n", uri, base_uri, emb->current_uri);
+	else
+		g_print ("Emptying current_uri\n");
 
 	g_free (old_uri);
 	g_free (old_base);
@@ -1490,6 +1532,8 @@ on_eos_event (BaconVideoWidget *bvw, TotemEmbedded *emb)
 			if (bacon_video_widget_is_seekable (emb->bvw) != FALSE) {
 				bacon_video_widget_pause (emb->bvw);
 				bacon_video_widget_seek (emb->bvw, 0.0, NULL);
+				if (start_play != FALSE)
+					totem_embedded_play (emb, NULL);
 			} else {
 				bacon_video_widget_close (emb->bvw);
 				totem_embedded_open_internal (emb, start_play, NULL /* FIXME? */);
@@ -2009,18 +2053,18 @@ totem_embedded_set_window (TotemEmbedded *embedded,
 	if (embedded->window != NULL) {
 		g_warning ("Viewer: Already have a window!");
 
-		g_set_error (error,
-			     TOTEM_EMBEDDED_ERROR_QUARK,
-			     TOTEM_EMBEDDED_SETWINDOW_HAVE_WINDOW,
-			     "Already have a window");
+		g_set_error_literal (error,
+                                     TOTEM_EMBEDDED_ERROR_QUARK,
+                                     TOTEM_EMBEDDED_SETWINDOW_HAVE_WINDOW,
+                                     "Already have a window");
 		return FALSE;
 	}
 
 	if (window == 0) {
-		g_set_error (error,
-			     TOTEM_EMBEDDED_ERROR_QUARK,
-			     TOTEM_EMBEDDED_SETWINDOW_INVALID_XID,
-			     "Invalid XID");
+		g_set_error_literal (error,
+                                     TOTEM_EMBEDDED_ERROR_QUARK,
+                                     TOTEM_EMBEDDED_SETWINDOW_INVALID_XID,
+                                     "Invalid XID");
 		return FALSE;
 	}
 
@@ -2163,7 +2207,6 @@ parse_plugin_type (const gchar *option_name,
 	           GError **error)
 {
 	const char types[TOTEM_PLUGIN_TYPE_LAST][12] = {
-		"basic",
 		"gmp",
 		"complex",
 		"narrowspace",
