@@ -36,6 +36,7 @@
 #include <string.h>
 #include <math.h>
 #include <stdlib.h>
+#include <fcntl.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include "bacon-video-widget.h"
@@ -51,7 +52,7 @@
 #endif
 
 /* The main() function controls progress in the first and last 10% */
-#define PRINT_PROGRESS(p) { g_printf ("%f%% complete\n", p); }
+#define PRINT_PROGRESS(p) { if (print_progress) g_printf ("%f%% complete\n", p); }
 #define MIN_PROGRESS 10.0
 #define MAX_PROGRESS 90.0
 
@@ -313,7 +314,7 @@ save_pixbuf (GdkPixbuf *pixbuf, const char *path,
 	int width, height;
 	GdkPixbuf *with_holes;
 	GError *err = NULL;
-	char *a_width, *a_height;
+	gboolean ret;
 
 	height = gdk_pixbuf_get_height (pixbuf);
 	width = gdk_pixbuf_get_width (pixbuf);
@@ -324,18 +325,22 @@ save_pixbuf (GdkPixbuf *pixbuf, const char *path,
 	else
 		with_holes = g_object_ref (pixbuf);
 
-	a_width = g_strdup_printf ("%d", width);
-	a_height = g_strdup_printf ("%d", height);
 
-	if (gdk_pixbuf_save (with_holes, path,
-				jpeg_output ? "jpeg" : "png", &err,
-				"tEXt::Thumb::Image::Width", a_width,
-				"tEXt::Thumb::Image::Height", a_height,
-				NULL) == FALSE)
-	{
-		g_free (a_width);
-		g_free (a_height);
+	if (jpeg_output == FALSE) {
+		char *a_width, *a_height;
 
+		a_width = g_strdup_printf ("%d", width);
+		a_height = g_strdup_printf ("%d", height);
+
+		ret = gdk_pixbuf_save (with_holes, path, "png", &err,
+				       "tEXt::Thumb::Image::Width", a_width,
+				       "tEXt::Thumb::Image::Height", a_height,
+				       NULL);
+	} else {
+		ret = gdk_pixbuf_save (with_holes, path, "jpeg", &err, NULL);
+	}
+
+	if (ret == FALSE) {
 		if (err != NULL) {
 			g_print ("totem-video-thumbnailer couldn't write the thumbnail '%s' for video '%s': %s\n", path, video_path, err->message);
 			g_error_free (err);
@@ -644,7 +649,16 @@ create_gallery (BaconVideoWidget *bvw, const char *input, const char *output)
 
 	/* Build the header information */
 	duration_text = totem_time_to_string (stream_length * 1000);
-	filename = g_path_get_basename (input);
+	filename = NULL;
+	if (strstr (input, "://")) {
+		char *local;
+		local = g_filename_from_uri (input, NULL, NULL);
+		filename = g_path_get_basename (local);
+		g_free (local);
+	}
+	if (filename == NULL)
+		filename = g_path_get_basename (input);
+
 	header_text = g_strdup_printf (_("<b>%s</b>: %s\n<b>%s</b>: %d\303\227%d\n<b>%s</b>: %s"),
 				       _("Filename"),
 				       filename,
@@ -776,6 +790,11 @@ int main (int argc, char *argv[])
 		return 1;
 	}
 
+	if (print_progress) {
+		fcntl (fileno (stdout), F_SETFL, O_NONBLOCK);
+		setbuf (stdout, NULL);
+	}
+
 	if (g_fatal_warnings) {
 		GLogLevelFlags fatal_mask;
 
